==> qtjambi-sensors-5.15.14-sources.jar: io/qt/sensors/QTapSensor.java <==
package io.qt.sensors;

import io.qt.*;


/**
 * <p>Convenience wrapper around QSensor</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qtapsensor.html">QTapSensor</a></p>
 */
public class QTapSensor extends io.qt.sensors.QSensor
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QTapSensor.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qtapsensor.html#returnDoubleTapEvents-prop">QTapSensor::returnDoubleTapEventsChanged(bool)</a></p>
     */
    @QtPropertyNotify(name="returnDoubleTapEvents")
    public final @NonNull Signal1<java.lang.@QtPrimitiveType@NonNull Boolean> returnDoubleTapEventsChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QTapSensor() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qtapsensor.html#QTapSensor">QTapSensor::QTapSensor(QObject*)</a></p>
     */
    public QTapSensor(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QTapSensor instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qsensor.html#reading-prop">QSensor::reading()const</a></p>
     */
    @QtUninvokable
    public final io.qt.sensors.@Nullable QTapReading reading(){
        return reading_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.sensors.QTapReading reading_native_constfct(long __this__nativeId);
    
    /**
     * <p>Kotlin property getter. In Java use {@link #returnDoubleTapEvents()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final boolean getReturnDoubleTapEvents() {
        return returnDoubleTapEvents();
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qtapsensor.html#returnDoubleTapEvents-prop">QTapSensor::returnDoubleTapEvents()const</a></p>
     */
    @QtPropertyReader(name="returnDoubleTapEvents")
    @QtUninvokable
    public final boolean returnDoubleTapEvents(){
        return returnDoubleTapEvents_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean returnDoubleTapEvents_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qtapsensor.html#returnDoubleTapEvents-prop">QTapSensor::setReturnDoubleTapEvents(bool)</a></p>
     */
    @QtPropertyWriter(name="returnDoubleTapEvents")
    @QtUninvokable
    public final void setReturnDoubleTapEvents(boolean returnDoubleTapEvents){
        setReturnDoubleTapEvents_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), returnDoubleTapEvents);
    }
    
    @QtUninvokable
    private native void setReturnDoubleTapEvents_native_bool(long __this__nativeId, boolean returnDoubleTapEvents);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QTapSensor(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QTapSensor(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QTapSensor instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-sensors-6.2.6-sources.jar: io/qt/sensors/QTapSensor.java <==
package io.qt.sensors;


/**
 * <p>Java wrapper for Qt class QTapSensor</p>
 */
public class QTapSensor extends io.qt.sensors.QSensor
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QTapSensor.class);
    

    @io.qt.QtPropertyNotify(name="returnDoubleTapEvents")
    public final Signal1<@io.qt.QtPrimitiveType Boolean> returnDoubleTapEventsChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QTapSensor(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QTapSensor() {
        this((io.qt.core.QObject)null);
    }
    
    public QTapSensor(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QTapSensor instance, io.qt.core.QObject parent);
    
    @io.qt.QtUninvokable
    public final io.qt.sensors.QTapReading reading(){
        return reading_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.sensors.QTapReading reading_native_constfct(long __this__nativeId);
    
    @io.qt.QtPropertyReader(name="returnDoubleTapEvents")
    @io.qt.QtUninvokable
    public final boolean returnDoubleTapEvents(){
        return returnDoubleTapEvents_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean returnDoubleTapEvents_native_constfct(long __this__nativeId);
    
    @io.qt.QtPropertyWriter(name="returnDoubleTapEvents")
    @io.qt.QtUninvokable
    public final void setReturnDoubleTapEvents(boolean returnDoubleTapEvents){
        setReturnDoubleTapEvents_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), returnDoubleTapEvents);
    }
    
    @io.qt.QtUninvokable
    private native void setReturnDoubleTapEvents_native_bool(long __this__nativeId, boolean returnDoubleTapEvents);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QTapSensor(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QTapSensor(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QTapSensor instance, QDeclarativeConstructor constructor);
    
}
